#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QGraphicsScene>
#include <QAbstractGraphicsShapeItem>
#include <QGraphicsRectItem>
#include <QGraphicsEllipseItem>
#include <QToolButton>

namespace Ui {
class MainWindow;
}

class ColorButton : public QToolButton
{
private :
    QString name;
    QColor color;
public :
    ColorButton (QString s);
protected:
    void mousePressEvent(QMouseEvent *event);
};

class Rectangle : public QGraphicsRectItem
{
protected:
    void dragEnterEvent(QGraphicsSceneDragDropEvent *event);
    void dropEvent(QGraphicsSceneDragDropEvent *event);
public:
    Rectangle ();
};

class Ellipse : public QGraphicsEllipseItem
{
protected:
    void dragEnterEvent(QGraphicsSceneDragDropEvent *event);
    void dropEvent(QGraphicsSceneDragDropEvent *event);
public:
    Ellipse ();
};

typedef QAbstractGraphicsShapeItem ShapeItem;

class ParamList : public QMap <QString, QString>
{
   public:
      int number (QString key, int default_value = 0);
};

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

    void readFile(QString fileName);

    Rectangle * createRectangle (QGraphicsItem * target,
                               ParamList param);

    Ellipse * createEllipse (QGraphicsItem * target,
                               ParamList param);

    void modifyShape (QGraphicsItem * target,
                      ShapeItem * shape,
                      ParamList param);

private:
    Ui::MainWindow * ui;
    QGraphicsScene * scene;
};

#endif // MAINWINDOW_H
